==> mdm-rpc-0.0.31-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/FranchiserProductPriceVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import java.io.Serializable;
import java.util.Date;

/**
 * 经销商各类型产品价格信息
 * User: wangfl
 * Date: 17/5/16
 * Time: 下午4:57
 */
public class FranchiserProductPriceVo implements Serializable {
    private static final long serialVersionUID = -2543362419266331458L;

    /**
     * 数据库中的id
     */
    private String id;

    /***
     * 经销商编码
     */
    private String franchiserCode;

    /**
     * 公司编码
     */
    private String companyCode;
    /**
     *产品编码
     */
    private String productCode;

    /**
     * 价格类型编码
     */
    private String priceTypeCode;

    /**
     * 价格类型名称
     */
    private String priceTypeName;

    /**
     * 价格
     */
    private String price;

    /**
     * 价格单位
     */
    private String unit;

    /**
     * 货币
     */
    private String currency;

    /**
     * 数量
     */
    private long num;

    /**
     * 创建时间
     */
    private Date createDate;
    /**
     * 最近更新时间
     */
    private Date updateDate;

    /**
     * 状态 0删除 1正常
     */
    private Integer enableStatus;

    /**
     * 有效开始时间
     */
    private Date startDate;

    /**
     * 有效结束时间
     */
    private Date endDate;
    /**
     * 01 新增 02 修改 03 删除
     */
    private String omact;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getFranchiserCode() {
        return franchiserCode;
    }

    public void setFranchiserCode(String franchiserCode) {
        this.franchiserCode = franchiserCode;
    }

    public String getCompanyCode() {
        return companyCode;
    }

    public void setCompanyCode(String companyCode) {
        this.companyCode = companyCode;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getPriceTypeCode() {
        return priceTypeCode;
    }

    public void setPriceTypeCode(String priceTypeCode) {
        this.priceTypeCode = priceTypeCode;
    }

    public String getPriceTypeName() {
        return priceTypeName;
    }

    public void setPriceTypeName(String priceTypeName) {
        this.priceTypeName = priceTypeName;
    }

    public String getPrice() {
        return price;
    }

    public void setPrice(String  price) {
        this.price = price;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public long getNum() {
        return num;
    }

    public void setNum(long num) {
        this.num = num;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getOmact() {
        return omact;
    }

    public void setOmact(String omact) {
        this.omact = omact;
    }
}

==> mdm-rpc-0.1.93-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/FranchiserProductPriceVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import java.io.Serializable;
import java.util.Date;

/**
 * 经销商各类型产品价格信息
 * User: wangfl
 * Date: 17/5/16
 * Time: 下午4:57
 */
public class FranchiserProductPriceVo implements Serializable {
    private static final long serialVersionUID = -2543362419266331458L;

    /**
     * 数据库中的id
     */
    private String id;

    /***
     * 经销商编码
     */
    private String franchiserCode;

    /**
     * 公司编码
     */
    private String companyCode;
    /**
     *产品编码
     */
    private String productCode;

    /**
     * 价格类型编码
     */
    private String priceTypeCode;

    /**
     * 价格类型名称
     */
    private String priceTypeName;

    /**
     * 价格
     */
    private long price;

    /**
     * 价格单位
     */
    private String unit;

    /**
     * 货币
     */
    private String currency;

    /**
     * 数量
     */
    private long num;

    /**
     * 创建时间
     */
    private Date createDate;
    /**
     * 最近更新时间
     */
    private Date updateDate;

    /**
     * 状态 0删除 1正常
     */
    private Integer enableStatus;

    /**
     * 有效开始时间
     */
    private Date startDate;

    /**
     * 有效结束时间
     */
    private Date endDate;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getFranchiserCode() {
        return franchiserCode;
    }

    public void setFranchiserCode(String franchiserCode) {
        this.franchiserCode = franchiserCode;
    }

    public String getCompanyCode() {
        return companyCode;
    }

    public void setCompanyCode(String companyCode) {
        this.companyCode = companyCode;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getPriceTypeCode() {
        return priceTypeCode;
    }

    public void setPriceTypeCode(String priceTypeCode) {
        this.priceTypeCode = priceTypeCode;
    }

    public String getPriceTypeName() {
        return priceTypeName;
    }

    public void setPriceTypeName(String priceTypeName) {
        this.priceTypeName = priceTypeName;
    }

    public long getPrice() {
        return price;
    }

    public void setPrice(long price) {
        this.price = price;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public long getNum() {
        return num;
    }

    public void setNum(long num) {
        this.num = num;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
}
